summaryrefslogtreecommitdiffstats
path: root/khtml/khtml_settings.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:35:07 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:35:07 -0600
commit703fb0c89c2eee56a1e613e67a446db9d4287929 (patch)
treedd8c5ca66075cd89c2638a2b48cf78386a9870a7 /khtml/khtml_settings.h
parent818e7abec3d5d3809b6b77293558678371c16b71 (diff)
downloadtdelibs-703fb0c89c2eee56a1e613e67a446db9d4287929.tar.gz
tdelibs-703fb0c89c2eee56a1e613e67a446db9d4287929.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'khtml/khtml_settings.h')
-rw-r--r--khtml/khtml_settings.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/khtml/khtml_settings.h b/khtml/khtml_settings.h
index bb089e5a8..4d68845f7 100644
--- a/khtml/khtml_settings.h
+++ b/khtml/khtml_settings.h
@@ -20,7 +20,7 @@
#ifndef __konq_htmlsettings_h__
#define __konq_htmlsettings_h__
-class KConfig;
+class TDEConfig;
#include <tqcolor.h>
#include <tqstring.h>
#include <tqstringlist.h>
@@ -108,11 +108,11 @@ public:
void init();
/** Read settings from @p config.
* @param config is a pointer to KConfig object.
* @param reset if true, settings are always set; if false,
* settings are only set if the config file has a corresponding key.
*/
- void init( KConfig * config, bool reset = true );
+ void init( TDEConfig * config, bool reset = true );
/**
* Destructor. Don't delete any instance by yourself.
@@ -193,13 +193,13 @@ public:
/** reads from @p config's current group, forcing initialization
* if @p reset is true.
* @param config is a pointer to KConfig object.
* @param reset true if initialization is to be forced.
* @param global true if the global domain is to be read.
* @param pd_settings will be initialised with the computed (inherited)
* settings.
*/
- void readDomainSettings(KConfig *config, bool reset,
+ void readDomainSettings(TDEConfig *config, bool reset,
bool global, KPerDomainSettings &pd_settings);
TQString settingsToCSS() const;
@@ -108,11 +108,11 @@ public:
void init();
/** Read settings from @p config.
- * @param config is a pointer to KConfig object.
+ * @param config is a pointer to TDEConfig object.
* @param reset if true, settings are always set; if false,
* settings are only set if the config file has a corresponding key.
@@ -193,13 +193,13 @@ public:
/** reads from @p config's current group, forcing initialization
* if @p reset is true.
- * @param config is a pointer to KConfig object.
+ * @param config is a pointer to TDEConfig object.
* @param reset true if initialization is to be forced.
* @param global true if the global domain is to be read.